@@ -1,6 +1,6 @@
 """
 Python interface for TeVCat (http://tevcat.uchicago.edu/)
-$Id: tevcat_all.py 17 2014-02-19 14:49:18Z oxon $
+$Id: tevcat_all.py 18 2014-02-20 12:15:00Z oxon $
 """
 
 import urllib
@@ -361,7 +361,7 @@ class Source(object):
         """
         Retruns True if the source is extended one.
         """
-        return self.extended
+        return self.ext
 
     def getCatalog(self):
         """
